/* ESP32_ThingSpeak 
 *  
 * Egyszerű ThingSpeak kliens, amely egy DHT22 
 * szenzorral mért adatait (hőmérséklet, rel. páratartalom)
 * GET metódussal küldi el a szerverre.
 * A DHT22 szenzor a GPIO23 kivezetéshez csatlakozik.
 * 
 * Tested with Arduino IDE 1.8.19 and ESP32 Arduino Core 2.0.2
 * /

#include <WiFi.h>
#include <HTTPClient.h>
#include "DHT.h"
#include "secrets.h"

#define DHTPIN          23     // GPIO23 pin for DHT sensor
DHT dht(DHTPIN, DHT22);
float t = 0.0;                 // temperature
float h = 0.0;                 // humidity
String server_url = "http://api.thingspeak.com/update?api_key=" + THINGSPEAK_WRITE_APIKEY;

void setup () {
  Serial.begin(115200);
  dht.begin();
  WiFi.mode(WIFI_STA);
  WiFi.begin(WIFI_SSID, WIFI_PASS);
  Serial.print("Connecting to ");
  Serial.print(WIFI_SSID);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println();
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
}

void loop() {
  float tnew = dht.readTemperature();
  if (!isnan(tnew)) t = tnew;
  float hnew = dht.readHumidity();
  if (!isnan(hnew)) h = hnew;
  String p1 = String("&field1=") + String(t, 1);
  String p2 = String("&field2=") + String(h, 1);
  Serial.println(p1 + p2);
  if (WiFi.status() == WL_CONNECTED) {     // Check WiFi connection status
    HTTPClient http;                       // Declare an object of class HTTPClient
    String server_request = server_url + p1 + p2;
    http.begin(server_request);            // Specify request destination and fields
    int httpCode = http.GET();             // Send the request
    if (httpCode > 0) {                    // Check the returning code
      Serial.print("HTTP Response code: ");
      Serial.println(httpCode);
      String payload = http.getString();   // Get the request response payload
      Serial.println(payload);             // Print the response payload
    }
    else {
      Serial.print("Error code: ");
      Serial.println(httpCode);
    }
    http.end();                            // Close connection
  }
  delay(20000);                            // Send a request every 20 seconds
}
